%% Ein einfaches SIR-Modell
%

%% Kontext
% Das SIR-Modell (susceptible-infected-removed model) beschreibt in sehr
% vereinfachter Form die Ausbreitung von ansteckenden Krankheiten mit
% Immunittsbildung.
%  
% Das Modell ist formuliert als System von drei Differentialgleichungen 1. Ordnung:
%
% $$\frac{dS}{dt}=-\frac{\beta IS}{N} $$
%
% $$\frac{dI}{dt}= \frac{\beta IS}{N}-\gamma I $$
% 
% $$\frac{dR}{dt}=\gamma I $$
%
% Darin steht $S(t)$ fr die Anzahl der suszeptiblen (anflligen) Personen,
% $I(t)$ ist die Zahl der Infizierten und $R(t)$ die aus dem Modell
% rausgenommenen Personen (alle, die nicht mehr infiziert werden knnen,
% weil sie immun oder tot sind). $N = S(t) + I(t) + R(t)$ ist die konstante
% Gesamtgre der Population. (Dieses Modell bercksichtigt also nicht die
% allgemeine demografische Entwicklung, also Geburten und nicht durch die
% Epidemie bedingte Todesflle; das liee sich aber mit wenigen
% Zusatz-Termen mit bercksichtigen).
%
% Der Parameter $\beta$ gibt an, wie viele enge Kontakte
% ein Individuum pro Tag durchschnittlich hat. (wobei nur ein Kontakt
% zwischen einem S- und einem I-Individuum zu einer Ansteckund fhrt; Kontakte vom Typ S-S,
% S-R, I-I und I-R bleiben folgenlos).
%
% Der Parameter $\gamma$ lsst sich einfacher in Form seines Reziprokwerts interpretieren
% als
%
% $\displaystyle \frac{1}{\gamma}$ Typische Zeitdauer der Infektion
%
% Mageblich fr die Dynamik der Epidemie ist die Basisreproduktionszahl 
%
% $$R_0 = \frac{\beta}{\gamma}\qquad . $$
%
% Dieser Wert gibt an, wie viele weitere Personen eine infizierte Person in
% der Anfangsphase der Epidemie, (wenn in der allgemeinen Population noch
% kaum jemand immun ist), im Durchscnitt ansteckt.
%
% Die Urheber dieses Modells, der Biochemiker William Ogilvy Kermack und
% der Militrarzt Anderson Gray McKendrick, konnten trotz der Einfachheit
% des Modells gut die Daten einer Pestepidemie in Bombay 1905/06
% modellieren. Nur etwas ber 100 Jahre spter, 2014, publizierten Harko
% and Koautoren eine exakte analytische Lsung dieses
% Differentialgleichungssystems. In aller Regel wird dieses
% Differentialgleichungssystem aber  numerisch gelst.
 
%% Modellparameter

beta = 0.4 ;
gamma = 0.04;
N = 1000000;

R0=beta/gamma

%% Die Funktion f definiert die Differentialgleichung
% Bezeichnung: y = [S;I;R], also y(1) steht fr S, y(2) fr I, y(3) fr R.

f = @(t,y)[ 
    - beta*y(2)*y(1)/N;
      beta*y(2)*y(1)/N - gamma*y(2);
      gamma*y(2) ];
%% Aufruf des Lsers mit passenden Anfangsbedingungen und Plot
% Der DG-Lser ode45 ist ein Allzweck-Standard-Verfahren.

ode45(f,[0 100],[N-10000, 10000,0])

%%
% Beschriftung und Kosmetik
title 'SIR-Modell'
xlabel 'Zeit t (Tage)'
ylabel 'Individuen in S, I, R'